#********************************************************************
#* Decompress the genome
#* By default: GRCh37 (excluding alternative loci, including
#*             unplaced), plus the Cambridge Reference Sequence for
#*             the mitochondrion (NC_012920.1).
#* You can use your own genome by substituting the "genome.fa.gz"
#* file, or add a "genome.fa" file and skip this decompression step.
#********************************************************************

if [ -s "genome.fa.gz" ];
then
	echo "Decompressing genome";
	gzip -dc genome.fa.gz > genome.fa;
	echo "Decompressing genome done";
	echo "Using genome.fa as reference genome";
elif [ -s "genome.fa" ]
then
	echo "Using genome.fa as reference genome";
else
	echo "genome.fa.gz or genome.fa not found";
	echo "Exiting script";
fi

#********************************************************************
#* Build 2Bwt index
#* This step includes running "soap3-dp-builder" and "BGS-Build"
#* For human genome, "soap3-dp-builder" comsumes about 1-2 hours and
#* "BGS-Build" consumes 1-3 minutes, depends on the CPU and IO speed.
#* "soap3-dp-builder" by default use 1/4 SA sampling (~9G memory
#* consumption during alignment), you can set "SaValueFreq=2" for 1/2
#* SA (~13G memory) and "SaValueFreq=1" for full SA (~17G memory) in
#* "soap3-dp-builder.ini" configuration file and rebuild the index.
#* Higher sampling rates consume more memory but deliver higher speed
#* during alignment. For GPU server with enough memory, we suggest to
#* use full SA in batch run.
#********************************************************************

echo
echo "Building 2Bwt index step 1"
./soap3-dp-builder genome.fa
echo "Building 2Bwt index step 1 done"
echo
echo "Building 2Bwt index step 2"
./BGS-Build genome.fa.index
echo "Building 2Bwt index step 2 done"

echo "Done."
