#********************************************************************
#* Check if GPU CUDA device is available and initialized correctly
#********************************************************************
nvidia-smi
if [ $? != 0 ]
then
	printf "Please ensure if the CUDA device is installed and correctly initialized.\nUse command 'sudo nvidia-smi' to initialize the CUDA device if your ensure the GPU is installed correctly.\nExiting script.\n";
	exit 0;
fi

#********************************************************************
#* Align in batch
#* genome.fa.index : 2Bwt index path.
#* align.list : batch configuration file.
#* -b 3 : output in BAM file format (2 for SAM)
#* -I : quality score in 64-base encoding
#* -c 0 : select the first available GPU device in list
#* -L 150: the maximum read length is 150bp
#* Caveat: index path and batch configuration file path should be
#*         defined before other parameters.
#********************************************************************

echo "Batch alignment"
./soap3-dp pair-multi ./genome.fa.index ./align.list -b 3 -I -c 0 -L 150
echo "Batch alignment done"

#********************************************************************
#* Align one lane a time
#* genome.fa.index : 2Bwt index path.
#* '*1.fq.gz': first read file (gzipped or plain)
#* '*2.fq.gz': second read file (gzipped or plain)
#* -o 'prefix': output path and prefix.
#* -A YH : sample name
#* -D 'name' : read group name
#* -R 'options' : read group options (\t as delimiter, "'" enclosed)
#* -b 3 : output in BAM file format (2 for SAM)
#* -I : quality score in 64-base encoding
#* -c 0 : select the first available GPU device in list
#* -L 150 : the maximum read length is 150bp
#* -u 1000 : maximum allowed insert size
#* -v 0 : minimum allowed insert size
#* Caveat: index path and read file paths should be
#*         defined before other parameters.
#********************************************************************

echo "One lane per run alignment"
./soap3-dp pair ./genome.fa.index ./110114_I481_FC81C7HABXX_L7_HUMiqvDBTDBAAPE_1.fq.gz ./110114_I481_FC81C7HABXX_L7_HUMiqvDBTDBAAPE_2.fq.gz -o ./110114_I481_FC81C7HABXX_L7_HUMiqvDBTDBAAPE_1-perLane -A YH -D 110114_I481_FC81C7HABXX_L7_HUMiqvDBTDBAAPE -R 'LB:HUMiqvDBTDBAAPE\tPL:ILLUMINA\tPU:110114_I481_FC81C7HABXX_L7' -b 3 -I -c 0 -L 100 -u 500 -v 0
./soap3-dp pair ./genome.fa.index ./120816_I269_FCC10KYACXX_L1_RDHUMYH3DEACPEI-131_1.fq.gz ./120816_I269_FCC10KYACXX_L1_RDHUMYH3DEACPEI-131_2.fq.gz -o ./120816_I269_FCC10KYACXX_L1_RDHUMYH3DEACPEI-131-perLane -A YH -D 120816_I269_FCC10KYACXX_L1_RDHUMYH3DEACPEI -R 'LB:RDHUMYH3DEACPEI-131\tPL:ILLUMINA\tPU:120816_I269_FCC10KYACXX_L1' -b 3 -I -c 0 -L 150 -u 1000 -v 0
echo "One lane per run alignment done"


#********************************************************************
#* Sort and merge results using samtools
#********************************************************************

echo "Sort and merge"
for i in 110114_I481_FC81C7HABXX_L7_HUMiqvDBTDBAAPE_1-batch 110114_I481_FC81C7HABXX_L7_HUMiqvDBTDBAAPE_1-perLane 120816_I269_FCC10KYACXX_L1_RDHUMYH3DEACPEI-131-batch 120816_I269_FCC10KYACXX_L1_RDHUMYH3DEACPEI-131-perLane;
do
	for j in ./$i.dpout.1 ./$i.gout.* ./$i.unpair;
	do
		./samtools sort $j $j;
	done;
	./samtools merge $i.bam ./$i.dpout.1.bam ./$i.gout.*.bam ./$i.unpair.bam;
	./samtools index $i.bam;
	echo "$i.bam successfully generated.";
done
echo "Sort and merge done"

echo "Done."

